/*
 *******************************************************************************
 *
 *  Copyright 2020 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.48";
const std::string RDB_META_DATA_ITEMS_DATE = "2021-04-16";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Angular notch filter parameters for window glass echoe"
    "s\",\"type\":\"object\",\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"],"
    "\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"amp"
    "litude_mean\":{\"description\":\"Mean amplitude [dB]\",\"type\":\"array\",\"item"
    "s\":{\"type\":\"number\"}},\"angle\":{\"description\":\"Angle [deg]\",\"type\":\"arr"
    "ay\",\"items\":{\"type\":\"number\"}},\"range_mean\":{\"description\":\"Mean range"
    " [m]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}}},\"title\":\"Angular "
    "Notch Filter\"}"
    ,
    /* example: */
    "{\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.7209"
    "13,2.680913,2.610913,2.530913,2.570913,2.570913],\"angle\":[14.0,15.0,16"
    ".0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"range_mean\":[0.094,0.094,"
    "0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}"
};

// Atmospheric Parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric Parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Atmospheric Parameters\",\"type\":\"object\",\"required\":[\"t"
    "emperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"amsl\",\"group_velo"
    "city\",\"attenuation\",\"wavelength\"],\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"properties\":{\"pressure\":{\"description\":\"Pressure "
    "along measurment path "
    "[mbar]\",\"type\":\"number\"},\"wavelength\":{\"description\":\"Laser wavelength"
    " [nm]\",\"type\":\"number\"},\"temperature\":{\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\",\"type\":\"number\"},\"pressure_sl\":{\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\",\"type\":\"number\"},\"amsl\":{\"description\":\"Height above mean sea "
    "level (AMSL) "
    "[m]\",\"type\":\"number\"},\"attenuation\":{\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\",\"type\":\"number\"},\"group_velocity\":{\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\",\"type\":\"number\"},\"rel_humidity\":{\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\",\"type\":\"number\"}},\"title\":\"Atmospheric Parameters\"}"
    ,
    /* example: */
    "{\"pressure\":970,\"wavelength\":1550,\"temperature\":7,\"pressure_sl\":970,\"a"
    "msl\":0,\"attenuation\":0.028125,\"group_velocity\":299711000.0,\"rel_humidi"
    "ty\":63}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Laser beam geometry details\",\"type\":\"object\",\"required"
    "\":[\"beam_exit_diameter\",\"beam_divergence\"],\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"properties\":{\"beam_divergence\":{\"type\":\"numb"
    "er\",\"description\":\"Beam divergence in far field [rad]\",\"exclusiveMinim"
    "um\":false,\"minimum\":0},\"beam_exit_diameter\":{\"type\":\"number\",\"descript"
    "ion\":\"Beam width at exit aperture "
    "[m]\",\"exclusiveMinimum\":false,\"minimum\":0}},\"title\":\"Beam Geometry\"}"
    ,
    /* example: */
    "{\"beam_divergence\":0.0003,\"beam_exit_diameter\":0.0072}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"List of control object type "
    "definitions\",\"type\":\"object\",\"title\":\"Control Object Catalog\",\"$schema"
    "\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"types\":{\"ty"
    "pe\":\"array\",\"uniqueItems\":true,\"items\":{\"oneOf\":[{\"$ref\":\"#/definition"
    "s/rectangle\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/defi"
    "nitions/chevron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/de"
    "finitions/cylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/defini"
    "tions/round_corner_cube_prism\"}],\"type\":\"object\"}}},\"definitions\":{\"ro"
    "und_corner_cube_prism\":{\"type\":\"object\",\"description\":\"round corner "
    "cube prism\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\","
    "\"description\":\"round corner cube prism specific properties\",\"propertie"
    "s\":{\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"enum\":["
    "\"round_corner_cube_prism\"]},\"diameter\":{\"type\":\"number\",\"description\":"
    "\"diameter in meters\",\"exclusiveMinimum\":true,\"minimum\":0},\"offset\":{\"t"
    "ype\":\"number\",\"description\":\"offset in meters, e.g. reflector constant"
    " (optional)\"}},\"required\":[\"shape\",\"diameter\"]}]},\"checkerboard2x2\":{\""
    "type\":\"object\",\"description\":\"checkerboard 2 by 2\",\"allOf\":[{\"$ref\":\"#"
    "/definitions/common\"},{\"type\":\"object\",\"description\":\"checkerboard "
    "specific properties\",\"properties\":{\"shape\":{\"type\":\"string\",\"descripti"
    "on\":\"shape identifier\",\"enum\":[\"checkerboard2x2\"]},\"square_length\":{\"t"
    "ype\":\"number\",\"description\":\"length of a square of the checkerboard in"
    " meters\",\"exclusiveMinimum\":true,\"minimum\":0}},\"required\":[\"shape\",\"sq"
    "uare_length\"]}]},\"common\":{\"type\":\"object\",\"description\":\"common "
    "object properties\",\"properties\":{\"shape\":{\"type\":\"string\",\"description"
    "\":\"shape identifier\",\"enum\":[\"rectangle\",\"checkerboard2x2\",\"chevron\",\""
    "circular_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism\"]},\"name\":"
    "{\"type\":\"string\",\"description\":\"unique type identifier\",\"minLength\":3}"
    ",\"description\":{\"type\":\"string\",\"description\":\"string describing the "
    "object\"},\"surface_type\":{\"type\":\"string\",\"description\":\"surface "
    "material type\",\"enum\":[\"retro_reflective_foil\",\"diffuse\"]}},\"required\""
    ":[\"name\",\"shape\"]},\"sphere\":{\"type\":\"object\",\"description\":\"sphere\",\"a"
    "llOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"description\":"
    "\"sphere specific properties\",\"properties\":{\"shape\":{\"type\":\"string\",\"d"
    "escription\":\"shape identifier\",\"enum\":[\"sphere\"]},\"diameter\":{\"type\":\""
    "number\",\"description\":\"diameter in meters\",\"exclusiveMinimum\":true,\"mi"
    "nimum\":0}},\"required\":[\"shape\",\"diameter\"]}]},\"rectangle\":{\"type\":\"obj"
    "ect\",\"description\":\"rectangle\",\"allOf\":[{\"$ref\":\"#/definitions/common\""
    "},{\"type\":\"object\",\"description\":\"rectangle specific properties\",\"prop"
    "erties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\"]},\"width\":{\"type"
    "\":\"number\",\"description\":\"width in meters\",\"exclusiveMinimum\":true,\"mi"
    "nimum\":0},\"length\":{\"type\":\"number\",\"description\":\"length in meters\",\""
    "exclusiveMinimum\":true,\"minimum\":0}},\"required\":[\"shape\",\"length\",\"wid"
    "th\"]}]},\"circular_disk\":{\"type\":\"object\",\"description\":\"circular disk\""
    ",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"descriptio"
    "n\":\"circular disk specific properties\",\"properties\":{\"shape\":{\"type\":\""
    "string\",\"description\":\"shape identifier\",\"enum\":[\"circular_disk\"]},\"di"
    "ameter\":{\"type\":\"number\",\"description\":\"diameter in meters\",\"exclusive"
    "Minimum\":true,\"minimum\":0},\"offset\":{\"type\":\"number\",\"description\":\"of"
    "fset in meters, e.g. reflector constant (optional)\"}},\"required\":[\"sha"
    "pe\",\"diameter\"]}]},\"chevron\":{\"type\":\"object\",\"description\":\"chevron\","
    "\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"description"
    "\":\"chevron specific properties\",\"properties\":{\"shape\":{\"type\":\"string\""
    ",\"description\":\"shape identifier\",\"enum\":[\"chevron\"]},\"outside_edge_le"
    "ngth\":{\"type\":\"number\",\"description\":\"length of the two outer edges in"
    " meters\",\"exclusiveMinimum\":true,\"minimum\":0},\"thickness\":{\"type\":\"num"
    "ber\",\"description\":\"thickness in meters\",\"exclusiveMinimum\":true,\"mini"
    "mum\":0}},\"required\":[\"shape\",\"outside_edge_length\",\"thickness\"]}]},\"cy"
    "linder\":{\"type\":\"object\",\"description\":\"cylinder\",\"allOf\":[{\"$ref\":\"#/"
    "definitions/common\"},{\"type\":\"object\",\"description\":\"cylinder specific"
    " properties\",\"properties\":{\"shape\":{\"type\":\"string\",\"description\":\"sha"
    "pe identifier\",\"enum\":[\"cylinder\"]},\"height\":{\"type\":\"number\",\"descrip"
    "tion\":\"height in meters\",\"exclusiveMinimum\":true,\"minimum\":0},\"diamete"
    "r\":{\"type\":\"number\",\"description\":\"diameter in meters\",\"exclusiveMinim"
    "um\":true,\"minimum\":0}},\"required\":[\"shape\",\"diameter\",\"height\"]}]}},\"r"
    "equired\":[\"types\"]}"
    ,
    /* example: */
    "{\"types\":[{\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "60x30\",\"description\":\"Rectangle (60cm x 30cm)\",\"width\":0.3,\"length\":0."
    "6},{\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "80x40\",\"description\":\"Rectangle (80cm x 40cm)\",\"width\":0.4,\"length\":0."
    "8},{\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "30\",\"description\":\"Checkerboard (square length: 30cm)\",\"square_length\""
    ":0.3},{\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "50\",\"description\":\"Checkerboard (square length: "
    "50cm)\",\"square_length\":0.5},{\"shape\":\"chevron\",\"name\":\"Chevron "
    "24''/4''\",\"description\":\"Chevron (a=24''; b=4'')\",\"outside_edge_length"
    "\":0.6096,\"thickness\":0.1016},{\"shape\":\"circular_disk\",\"name\":\"Circular"
    " Disk 50\",\"description\":\" Circular Disk (diameter: 50cm)\",\"diameter\":0"
    ".5,\"surface_type\":\"diffuse\"},{\"shape\":\"circular_disk\",\"name\":\"RIEGL "
    "flat reflector 50 mm\",\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"offset\":0.0,\"surface_type\":\"retro_reflective_f"
    "oil\",\"diameter\":0.05},{\"shape\":\"circular_disk\",\"name\":\"RIEGL flat "
    "reflector 100 mm\",\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"offset\":0.0,\"surface_type\":\"retro_reflective_f"
    "oil\",\"diameter\":0.1},{\"shape\":\"circular_disk\",\"name\":\"RIEGL flat "
    "reflector 150 mm\",\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"offset\":0.0,\"surface_type\":\"retro_reflective_f"
    "oil\",\"diameter\":0.15},{\"shape\":\"cylinder\",\"name\":\"RIEGL cylindrical "
    "reflector 50 mm\",\"description\":\"cylindrical reflector from "
    "retro-reflective foil\",\"surface_type\":\"retro_reflective_foil\",\"height\""
    ":0.05,\"diameter\":0.05},{\"shape\":\"cylinder\",\"name\":\"RIEGL cylindrical "
    "reflector 100 mm\",\"description\":\"cylindrical reflector from "
    "retro-reflective foil\",\"surface_type\":\"retro_reflective_foil\",\"height\""
    ":0.1,\"diameter\":0.1},{\"shape\":\"sphere\",\"name\":\"Sphere 200 "
    "mm\",\"description\":\"Sphere (diameter: 200 "
    "mm)\",\"diameter\":0.2},{\"shape\":\"round_corner_cube_prism\",\"name\":\"Corner"
    " Cube Prism 50 mm\",\"description\":\"round corner cube "
    "prism\",\"diameter\":0.05,\"offset\":0.0}],\"comments\":[\"This file contains "
    "a list of control object types (aka. 'catalog').\",\"Each type is "
    "described by an object,\",\"which must contain at least the following "
    "parameters:\",\"  - name: unique identifier of the type\",\"  - shape: one"
    " of the following supported shapes:\",\"      - rectangle\",\"      - "
    "checkerboard2x2\",\"      - chevron\",\"      - circular_disk\",\"      - "
    "cylinder\",\"      - sphere\",\"      - "
    "round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height:  height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about the control object "
    "reference file\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"p"
    "roperties\":{\"reference_file\":{\"description\":\"Reference to a control "
    "object file\",\"type\":\"object\",\"properties\":{\"file_path\":{\"type\":\"string"
    "\",\"description\":\"Path of the control object file relative to referring"
    " file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC "
    "4122)\"}},\"required\":[\"file_uuid\",\"file_path\"]}},\"title\":\"Control "
    "Object Reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Detection probability as a function of amplitude\",\"typ"
    "e\":\"object\",\"required\":[\"amplitude\",\"detection_probability\"],\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"detection_pr"
    "obability\":{\"description\":\"Detection probability [0..1]\",\"type\":\"array"
    "\",\"items\":{\"type\":\"number\"}},\"amplitude\":{\"description\":\"Amplitude "
    "[dB]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}}},\"title\":\"Detection "
    "Probability\"}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the device used to acquire the point clo"
    "ud\",\"type\":\"object\",\"required\":[\"device_type\",\"serial_number\"],\"$schem"
    "a\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"channel_te"
    "xt\":{\"type\":\"string\",\"description\":\"Optional channel description (e.g."
    " 'Green Channel' for multi-channel "
    "devices)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"channel_number\":{\"type\":\"integer\",\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"exclusiveMi"
    "nimum\":false,\"minimum\":0},\"serial_number\":{\"type\":\"string\",\"descriptio"
    "n\":\"Device serial number (e.g. "
    "S2221234)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. VZ-400i)\"}},\"title\":\"Device Information\"}"
    ,
    /* example: */
    "{\"channel_text\":\"\",\"device_build\":\"\",\"device_name\":\"Scanner 1\",\"channe"
    "l_number\":0,\"serial_number\":\"S2221234\",\"device_type\":\"VZ-400i\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scanner device geometry details\",\"type\":\"object\",\"requ"
    "ired\":[\"primary\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"properties\":{\"primary\":{\"type\":\"object\",\"description\":\"Primary device"
    " geometry structure (mandatory)\",\"properties\":{\"ID\":{\"type\":\"array\",\"m"
    "inItems\":2,\"description\":\"Structure identifier\",\"maxItems\":2,\"items\":{"
    "\"type\":\"integer\"}},\"content\":{\"type\":\"array\",\"description\":\"Internal "
    "calibration values\",\"items\":{\"type\":\"number\"}}},\"required\":[\"ID\",\"cont"
    "ent\"]},\"secondary\":{\"type\":\"object\",\"description\":\"Additional device "
    "geometry structure (optional)\",\"properties\":{\"ID\":{\"type\":\"array\",\"min"
    "Items\":2,\"description\":\"Structure identifier\",\"maxItems\":2,\"items\":{\"t"
    "ype\":\"integer\"}},\"content\":{\"type\":\"array\",\"description\":\"Internal "
    "calibration values\",\"items\":{\"type\":\"number\"}}},\"required\":[\"ID\",\"cont"
    "ent\"]},\"amu\":{\"type\":\"object\",\"description\":\"Angle Measurement "
    "Unit\",\"properties\":{\"frameCC\":{\"type\":\"number\",\"description\":\"Frame "
    "Circle Count (number of LSBs per full rotation about frame axis)\",\"exc"
    "lusiveMinimum\":false,\"minimum\":0},\"lineCC\":{\"type\":\"number\",\"descripti"
    "on\":\"Line Circle Count (number of LSBs per full rotation about line "
    "axis)\",\"exclusiveMinimum\":false,\"minimum\":0}}}},\"title\":\"Device "
    "Geometry\"}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[4,0],\"content\":[0]},\"secondary\":{\"ID\":[91,0],\"conten"
    "t\":[0]},\"amu\":{\"frameCC\":124000,\"lineCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scanner passive channel device geometry details\",\"type"
    "\":\"object\",\"required\":[\"primary\"],\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"properties\":{\"primary\":{\"type\":\"object\",\"description\""
    ":\"Primary device geometry structure (mandatory)\",\"properties\":{\"ID\":{\""
    "type\":\"array\",\"minItems\":2,\"description\":\"Structure identifier\",\"maxIt"
    "ems\":2,\"items\":{\"type\":\"integer\"}},\"content\":{\"type\":\"array\",\"descript"
    "ion\":\"Internal calibration values\",\"items\":{\"type\":\"number\"}}},\"requir"
    "ed\":[\"ID\",\"content\"]}},\"title\":\"Device Geometry Passive Channel\"}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[143,0],\"content\":[0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Limits of the measured values output "
    "by the device. The limits depend on the device type, measurement "
    "program and/or scan pattern.\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"properties\":{\"deviation_minimum\":{\"description\":\"Minimum "
    "possible pulse shape deviation.\",\"type\":\"number\"},\"mta_zone_count_maxi"
    "mum\":{\"description\":\"Maximum number of MTA "
    "zones.\",\"type\":\"number\"},\"amplitude_minimum\":{\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\",\"type\":\"number\"},\"reflectance_minimum\":{\"description\":\"Minimum "
    "possible reflectance in dB.\",\"type\":\"number\"},\"background_radiation_ma"
    "ximum\":{\"description\":\"Maximum possible background "
    "radiation.\",\"type\":\"number\"},\"range_maximum\":{\"description\":\"Maximum "
    "possible range in "
    "meters.\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum "
    "possible range in "
    "meters.\",\"type\":\"number\"},\"echo_count_maximum\":{\"description\":\"Maximum"
    " number of echoes a laser shot can "
    "have.\",\"type\":\"number\"},\"amplitude_maximum\":{\"description\":\"Maximum "
    "possible amplitude in "
    "dB.\",\"type\":\"number\"},\"reflectance_maximum\":{\"description\":\"Maximum "
    "possible reflectance in dB.\",\"type\":\"number\"},\"background_radiation_mi"
    "nimum\":{\"description\":\"Minimum possible background radiation.\",\"type\":"
    "\"number\"},\"deviation_maximum\":{\"description\":\"Maximum possible pulse "
    "shape deviation.\",\"type\":\"number\"}},\"title\":\"Device Output Limits\"}"
    ,
    /* example: */
    "{\"range_minimum\":2.9,\"range_maximum\":10000.0,\"deviation_minimum\":-1,\"a"
    "mplitude_minimum\":0.0,\"amplitude_maximum\":100.0,\"reflectance_minimum\":"
    "-100.0,\"background_radiation_maximum\":0,\"background_radiation_minimum\""
    ":0,\"deviation_maximum\":32767,\"mta_zone_count_maximum\":7,\"reflectance_m"
    "aximum\":100.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about echo files\",\"type\":\"object\",\"required\":["
    "\"echo_file\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"prop"
    "erties\":{\"echo_file\":{\"type\":\"object\",\"properties\":{\"file_extension\":{"
    "\"type\":\"string\",\"description\":\"Echo file extension, without the "
    "leading dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"}},\"required\":[\"file_extension\"]}},\"title\":\"Echo Information\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_extension\":\"owp\",\"file_uuid\":\"26a03615-67c0-4bea-8"
    "fe8-c577378fe661\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^[0-9]+$\":{\"description\":\"one field per "
    "channel, field name is channel "
    "index\",\"$ref\":\"#/definitions/channel\"}},\"description\":\"Details for "
    "exponential decomposition of full waveform "
    "data\",\"type\":\"object\",\"title\":\"Exponential Decomposition\",\"additionalP"
    "roperties\":false,\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "definitions\":{\"channel\":{\"type\":\"object\",\"properties\":{\"delay\":{\"type\""
    ":\"number\",\"description\":\"delay calibration in "
    "seconds\"},\"a_lin\":{\"exclusiveMaximum\":false,\"description\":\"relative "
    "linear amplitude range [0..1]\",\"type\":\"number\",\"maximum\":1,\"exclusiveM"
    "inimum\":false,\"minimum\":0},\"parameter\":{\"type\":\"object\",\"description\":"
    "\"parameters of the syswave exponential "
    "sum\",\"properties\":{\"omega\":{\"type\":\"array\",\"description\":\"angular "
    "frequency in "
    "Hz\",\"items\":{\"type\":\"number\"}},\"A\":{\"type\":\"array\",\"description\":\"real"
    " part of amplitude factor in units of full-scale\",\"items\":{\"type\":\"num"
    "ber\"}},\"B\":{\"type\":\"array\",\"description\":\"imaginary part of amplitude "
    "factor in units of full-scale\",\"items\":{\"type\":\"number\"}},\"gamma\":{\"ty"
    "pe\":\"array\",\"description\":\"decay in 1/second\",\"items\":{\"type\":\"number\""
    "}}},\"required\":[\"A\",\"B\",\"gamma\",\"omega\"]},\"scale\":{\"type\":\"number\",\"de"
    "scription\":\"amplitude "
    "calibration\"}},\"required\":[\"delay\",\"scale\",\"parameter\"]}}}"
    ,
    /* example: */
    "{\"0\":{\"delay\":3.783458418887631e-09,\"a_lin\":0.27,\"parameter\":{\"omega\":"
    "[352020896.0,3647927552.0,-1977987072.0],\"A\":[0.9772450923919678,0.335"
    "4335129261017,-1.312678575515747],\"B\":[-3.9813032150268555,0.086220309"
    "13829803,-0.3152860999107361],\"gamma\":[-1094726528.0,-769562752.0,-848"
    "000064.0]},\"scale\":1.0},\"1\":{\"delay\":3.5e-09,\"a_lin\":0.9,\"parameter\":{"
    "\"omega\":[352020896.0,3647927552.0,-1977987072.0],\"A\":[0.9,0.3,-1.3],\"B"
    "\":[-3.9,0.0,-0.3],\"gamma\":[-1094726528.0,-769562752.0,-848000064.0]},\""
    "scale\":1.0}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"riegl.gaussian_decomposition contains information "
    "relevant for extracting calibrated amplitudes and calibrated ranges "
    "from a Gaussian decomposition of full waveform data. This information "
    "is contained in a table with five columns. Two columns are to be used "
    "as input: amplitude_lsb_low_power and amplitude_lsb_high_power. The "
    "other three columns provide the outputs. Amplitude_db gives the "
    "calibrated amplitude in the optical regime in decibels. The range "
    "offset columns provide additive range offsets, given in units of "
    "seconds, for each channel.\",\"type\":\"object\",\"required\":[\"amplitude_lsb"
    "_low_power\",\"amplitude_lsb_high_power\",\"amplitude_db\",\"range_offset_se"
    "c_low_power\",\"range_offset_sec_high_power\"],\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"properties\":{\"amplitude_lsb_low_power\":{\"ty"
    "pe\":\"array\",\"items\":{\"type\":\"number\"}},\"range_offset_sec_low_power\":{\""
    "type\":\"array\",\"items\":{\"type\":\"number\"}},\"range_offset_sec_high_power\""
    ":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_lsb_high_power\""
    ":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_db\":{\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"number\"}}},\"title\":\"Gaussian Decomposition\"}"
    ,
    /* example: */
    "{\"amplitude_lsb_low_power\":[],\"range_offset_sec_low_power\":[],\"range_o"
    "ffset_sec_high_power\":[],\"amplitude_lsb_high_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud Georeferencing Information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud Georeferencing Information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Point cloud Georeferencing Information"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"p"
    "ose\":{\"minItems\":4,\"description\":\"Coordinate Transformation Matrix to "
    "transform from File Coordinate System to Global Coordinate Reference "
    "System. 4x4 matrix stored as two dimensional array, row major order.\","
    "\"type\":\"array\",\"maxItems\":4,\"items\":{\"type\":\"array\",\"minItems\":4,\"desc"
    "ription\":\"rows\",\"maxItems\":4,\"items\":{\"type\":\"number\",\"description\":\"c"
    "olumns\"}}},\"crs\":{\"description\":\"Global Coordinate Reference System. "
    "Please note that only 3D Cartesian Coordinate Systems are allowed.\",\"t"
    "ype\":\"object\",\"properties\":{\"name\":{\"type\":\"string\",\"description\":\"Coo"
    "rdinate reference system "
    "name\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"},\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG "
    "code\",\"minimum\":0}}}},\"title\":\"Geo Tag\"}"
    ,
    /* example: */
    "{\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063"
    "882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113"
    "8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0"
    ".0,0.0,0.0,1.0]],\"crs\":{\"name\":\"WGS84 "
    "Geocentric\",\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROI"
    "D[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AU"
    "THORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AU"
    "THORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTH"
    "ORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\"
    "\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"epsg\":4978}}"
};

// Geometric Scale Factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric Scale Factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"number\",\"description\":\"Geometric Scale Factor applied to "
    "point coordinates\",\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"exclusiveMinimum\":true,\"minimum\":0}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Parameters used for georeferencing of "
    "the point cloud\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "properties\":{\"socs_to_rocs_matrix\":{\"minItems\":4,\"description\":\"Coordi"
    "nate Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Record Coordinate System. 4x4 matrix stored as two "
    "dimensional array, row major order.\",\"type\":\"array\",\"maxItems\":4,\"item"
    "s\":{\"type\":\"array\",\"minItems\":4,\"description\":\"rows\",\"maxItems\":4,\"ite"
    "ms\":{\"type\":\"number\",\"description\":\"columns\"}}},\"trajectory_file\":{\"de"
    "scription\":\"Trajectory data used for georeferencing of the point cloud"
    "\",\"type\":\"object\",\"properties\":{\"file_extension\":{\"type\":\"string\",\"des"
    "cription\":\"Trajectory file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"required\":[\"file_extension\"]},\"trajec"
    "tory_offsets\":{\"description\":\"Correction offsets applied to the "
    "trajectory data\",\"type\":\"object\",\"properties\":{\"offset_time\":{\"descrip"
    "tion\":\"[s]\",\"type\":\"number\"},\"offset_roll\":{\"description\":\"[deg]\",\"typ"
    "e\":\"number\"},\"offset_pitch\":{\"description\":\"[deg]\",\"type\":\"number\"},\"v"
    "ersion\":{\"description\":\"Meaning of offset values and how to apply "
    "them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(yaw_offset)*Ry(pitch_offset"
    ")*Rx(roll_offset)\",\"type\":\"integer\"},\"offset_east\":{\"description\":\"[m]"
    "\",\"type\":\"number\"},\"offset_height\":{\"description\":\"[m]\",\"type\":\"number"
    "\"},\"offset_north\":{\"description\":\"[m]\",\"type\":\"number\"},\"offset_yaw\":{"
    "\"description\":\"[deg]\",\"type\":\"number\"}}},\"body_coordinate_system_type\""
    ":{\"description\":\"BODY coordinate frame (NED: North-East-Down, ENU: "
    "East-North-Up), default: NED\",\"type\":\"string\",\"enum\":[\"NED\",\"ENU\"]},\"s"
    "ocs_to_body_matrix\":{\"minItems\":4,\"description\":\"Coordinate "
    "Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\",\"type\":\"array\",\"maxItems\":4,\"items\":{\"type\":"
    "\"array\",\"minItems\":4,\"description\":\"rows\",\"maxItems\":4,\"items\":{\"type\""
    ":\"number\",\"description\":\"columns\"}}}},\"title\":\"Georeferencing "
    "Parameters\"}"
    ,
    /* example: */
    "{\"trajectory_file\":{\"file_extension\":\"pofx\",\"file_uuid\":\"93a03615-66c0"
    "-4bea-8ff8-c577378fe660\"},\"trajectory_offsets\":{\"offset_time\":18.007,\""
    "offset_roll\":0.03,\"offset_pitch\":0.01,\"version\":0,\"offset_east\":0.15,\""
    "offset_height\":-0.2,\"offset_north\":0.07,\"offset_yaw\":-0.45},\"body_coor"
    "dinate_system_type\":\"NED\",\"socs_to_body_matrix\":[[-0.269827776749716,-"
    "0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051"
    "7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,"
    "0.0],[0.0,0.0,0.0,1.0]]}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"minItems\":1,\"description"
    "\":\"Each field of the object represents a feature and holds a list of "
    "license keys, where the field name is the feature "
    "name.\",\"items\":{\"type\":\"string\",\"description\":\"License key (example: "
    "'46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"}}},\"description\":\"License keys for software features\",\"typ"
    "e\":\"object\",\"additionalProperties\":false,\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"title\":\"Software License Keys\"}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA "
    "- 8D2ED557\"],\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Parameters for MTA processing\",\"$schem"
    "a\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"zone_count"
    "\":{\"maximum\":255,\"description\":\"Maximum number of MTA zones.\",\"type\":\""
    "integer\",\"minimum\":0},\"zone_width\":{\"description\":\"Width of a MTA zone"
    " in meter.\",\"type\":\"number\",\"minimum\":0},\"modulation_depth\":{\"descript"
    "ion\":\"Depth of pulse position modulation in "
    "meter.\",\"type\":\"number\",\"minimum\":0}},\"title\":\"MTA Settings\"}"
    ,
    /* example: */
    "{\"zone_count\":23,\"zone_width\":149.896225,\"modulation_depth\":9.368514}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Lookup table for range correction based on raw range\","
    "\"type\":\"object\",\"required\":[\"delta\",\"content\"],\"$schema\":\"http://json-"
    "schema.org/draft-04/schema#\",\"properties\":{\"delta\":{\"type\":\"number\",\"d"
    "escription\":\"Delta between table entries [m], first entry is at range "
    "= 0 "
    "m\"},\"content\":{\"type\":\"array\",\"minItems\":1,\"description\":\"Correction "
    "value [m] to be added to the raw "
    "range\",\"maxItems\":2000,\"items\":{\"type\":\"number\"}}},\"title\":\"Near Range"
    " Correction Table\"}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Standard deviation for range and amplitude as a "
    "function of amplitude\",\"type\":\"object\",\"required\":[\"amplitude\",\"range_"
    "sigma\",\"amplitude_sigma\"],\"$schema\":\"http://json-schema.org/draft-04/s"
    "chema#\",\"properties\":{\"range_sigma\":{\"description\":\"Sigma range [m]\",\""
    "type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude\":{\"description\":\"A"
    "mplitude [dB]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_si"
    "gma\":{\"description\":\"Sigma amplitude "
    "[dB]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}}},\"title\":\"Noise "
    "Estimates\"}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0"
    "],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0."
    "432,0.39,0.354]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Notch filter parameters for window glass echoes\",\"type"
    "\":\"object\",\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maxi"
    "mum\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\""
    ":{\"range_maximum\":{\"description\":\"Maximum range "
    "[m]\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum range "
    "[m]\",\"type\":\"number\"},\"amplitude_maximum\":{\"description\":\"Maximum "
    "amplitude [dB]\",\"type\":\"number\",\"minimum\":0}},\"title\":\"Notch Filter\"}"
    ,
    /* example: */
    "{\"range_maximum\":0.2,\"range_minimum\":-0.5,\"amplitude_maximum\":18.0}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the pixels contained in the "
    "file\",\"type\":\"object\",\"title\":\"Pixel Information\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"properties\":{\"size\":{\"description\":\"S"
    "ize of pixels in file coordinate system.\",\"$ref\":\"#/definitions/pixel_"
    "size\"},\"size_llcs\":{\"description\":\"Size of pixels in a locally "
    "levelled cartesian coordinate system (xy). This is only used for "
    "pixels based on a map projection.\",\"$ref\":\"#/definitions/pixel_size\"}}"
    ",\"definitions\":{\"pixel_size\":{\"minItems\":2,\"description\":\"Size of "
    "pixels.\",\"type\":\"array\",\"maxItems\":2,\"items\":{\"description\":\"Length of"
    " pixel edge [m].\",\"type\":\"number\",\"minimum\":0}}},\"required\":[\"size\"]}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395],\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the plane patch matching "
    "process\",\"type\":\"object\",\"title\":\"Plane Patch Matching\",\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"properties\":{\"plane_patch_file_"
    "one\":{\"description\":\"Reference to the plane patch file one\",\"$ref\":\"#/"
    "definitions/file_reference\"},\"plane_patch_file_two\":{\"description\":\"Re"
    "ference to the plane patch file two\",\"$ref\":\"#/definitions/file_refere"
    "nce\"}},\"definitions\":{\"file_reference\":{\"description\":\"Reference to a "
    "plane patch file\",\"type\":\"object\",\"properties\":{\"file_path\":{\"type\":\"s"
    "tring\",\"description\":\"Path of the plane patch file relative to the "
    "match file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch "
    "file's Universally Unique Identifier (RFC 4122)\"}},\"required\":[\"file_u"
    "uid\",\"file_path\"]}},\"required\":[\"plane_patch_file_one\",\"plane_patch_fi"
    "le_two\"]}"
    ,
    /* example: */
    "{\"plane_patch_file_one\":{\"file_path\":\"Record009_Line001/191025_121410_"
    "Scanner_1.ptch\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"},\"p"
    "lane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d509"
    "-a64e-49ce-8b14-ff3130fbefa9\"}}"
};

// Statistics about plane patches found by Plane Patch Extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by Plane Patch Extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Statistics about plane patches found "
    "by Plane Patch Extractor\",\"$schema\":\"http://json-schema.org/draft-04/s"
    "chema#\",\"properties\":{\"total_area\":{\"description\":\"sum of all plane "
    "patch areas [m\\u00b2]\",\"type\":\"number\"},\"total_horizontal_area\":{\"desc"
    "ription\":\"sum of all plane patch areas projected to horizontal plane "
    "[m\\u00b2]\",\"type\":\"number\"}},\"title\":\"Plane Patch Statistics\"}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Settings and classes for plane slope "
    "classification\",\"type\":\"object\",\"title\":\"Plane Slope Class Info\",\"$sch"
    "ema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"settings"
    "\":{\"description\":\"Classification settings, details see documentation "
    "of rdbplanes\",\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/method-1"
    "\"},{\"$ref\":\"#/definitions/method-2\"}]},\"classes\":{\"patternProperties\":"
    "{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"one field per class, field"
    " name is class number, field value is class "
    "name\"}},\"description\":\"Class definition table\",\"type\":\"object\",\"additi"
    "onalProperties\":false}},\"definitions\":{\"method-1\":{\"description\":\"Clas"
    "sification method 1\",\"type\":\"object\",\"properties\":{\"plane_classificati"
    "on_method\":{\"maximum\":1,\"description\":\"method ID (=1)\",\"type\":\"integer"
    "\",\"minimum\":1},\"maximum_inclination_angle_horizontal\":{\"maximum\":360.0"
    ",\"description\":\"maximum inclination angle of horizontal plane patches "
    "[deg]\",\"type\":\"number\",\"minimum\":-360.0}},\"required\":[\"plane_classific"
    "ation_method\",\"maximum_inclination_angle_horizontal\"]},\"method-2\":{\"de"
    "scription\":\"Classification method 2\",\"type\":\"object\",\"properties\":{\"pl"
    "ane_classification_method\":{\"maximum\":2,\"description\":\"method ID (=2)\""
    ",\"type\":\"integer\",\"minimum\":2},\"sloping_plane_classes_minimum_angle\":{"
    "\"maximum\":360.0,\"description\":\"minimum inclination angle of sloping "
    "plane patches [deg]\",\"type\":\"number\",\"minimum\":-360.0},\"sloping_plane_"
    "classes_maximum_angle\":{\"maximum\":360.0,\"description\":\"maximum "
    "inclination angle of sloping plane patches [deg]\",\"type\":\"number\",\"min"
    "imum\":-360.0}},\"required\":[\"plane_classification_method\",\"sloping_plan"
    "e_classes_minimum_angle\",\"sloping_plane_classes_maximum_angle\"]}},\"req"
    "uired\":[\"settings\",\"classes\"]}"
    ,
    /* example: */
    "{\"settings\":{\"plane_classification_method\":2,\"sloping_plane_classes_mi"
    "nimum_angle\":10.0,\"sloping_plane_classes_maximum_angle\":70.0},\"classes"
    "\":{\"6\":\"vertical, pointing east\",\"14\":\"horizontal, pointing "
    "down\",\"7\":\"vertical, pointing south\",\"10\":\"sloping, pointing down and "
    "east\",\"9\":\"vertical, pointing west\",\"1\":\"horizontal, pointing "
    "up\",\"3\":\"sloping, pointing up and south\",\"11\":\"sloping, pointing down "
    "and south\",\"13\":\"sloping, pointing down and west\",\"12\":\"sloping, "
    "pointing down and north\",\"8\":\"vertical, pointing north\",\"4\":\"sloping, "
    "pointing up and north\",\"5\":\"sloping, pointing up and "
    "west\",\"2\":\"sloping, pointing up and east\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"minItems\":1,\"description"
    "\":\"Each field of the object represents a point attribute group and "
    "holds a list of point attributes, where the field name is the group "
    "name.\",\"items\":{\"type\":\"string\",\"description\":\"Point attribute full "
    "name or name pattern (perl regular expression "
    "syntax)\"}}},\"description\":\"Grouping and sorting of point attributes "
    "for visualization purposes\",\"type\":\"object\",\"additionalProperties\":fal"
    "se,\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point "
    "Attribute Groups\"}"
    ,
    /* example: */
    "{\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.de"
    "viation\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Other A"
    "ttributes\":[\"riegl.selected\",\"riegl.visible\"],\"Coordinates/Vectors\":[\""
    "riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl.phi\"],\"Time\":[\"riegl.tim"
    "estamp\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about point cloud files\",\"$sch"
    "ema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"field_of"
    "_application\":{\"type\":\"string\",\"description\":\"Field of application\",\"e"
    "num\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]},\"pro"
    "ject\":{\"type\":\"string\",\"description\":\"Project name\"},\"comments\":{\"type"
    "\":\"string\",\"description\":\"Comments\"}},\"title\":\"Point Cloud "
    "Information\"}"
    ,
    /* example: */
    "{\"field_of_application\":\"ALS\",\"project\":\"Campaign 4\",\"comments\":\"Line "
    "3\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Estimated position and orientation information as "
    "measured by GNSS, IMU or inclination sensors\",\"type\":\"object\",\"require"
    "d\":[\"orientation\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"properties\":{\"orientation\":{\"type\":\"object\",\"description\":\"Orientati"
    "on values and orientation accuracies, measured with IMU or inclination"
    " sensors.\",\"properties\":{\"pitch_accuracy\":{\"type\":\"number\",\"descriptio"
    "n\":\"Pitch angle accuracy [deg]\",\"exclusiveMinimum\":true,\"minimum\":0},\""
    "yaw_accuracy\":{\"type\":\"number\",\"description\":\"Yaw angle accuracy [deg]"
    "\",\"exclusiveMinimum\":true,\"minimum\":0},\"pitch\":{\"type\":\"number\",\"maxim"
    "um\":360,\"description\":\"Pitch angle about scanner Y-axis [deg]\",\"minimu"
    "m\":-360},\"roll_accuracy\":{\"type\":\"number\",\"description\":\"Roll angle "
    "accuracy [deg]\",\"exclusiveMinimum\":true,\"minimum\":0},\"roll\":{\"type\":\"n"
    "umber\",\"maximum\":360,\"description\":\"Roll angle about scanner X-axis [d"
    "eg]\",\"minimum\":-360},\"yaw\":{\"type\":\"number\",\"maximum\":360,\"description"
    "\":\"Yaw angle about scanner Z-axis [deg]\",\"minimum\":-360}},\"required\":["
    "\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy\"]}"
    ",\"barometric_height_amsl\":{\"type\":\"number\",\"description\":\"Altitude "
    "determined based on the atmospheric pressure according to the standard"
    " atmosphere laws "
    "[m].\"},\"position\":{\"type\":\"object\",\"description\":\"Position coordinates"
    " and position accuracy values as measured by GNSS in the specified "
    "Coordinate Reference System (CRS)\",\"properties\":{\"coordinate_1\":{\"type"
    "\":\"number\",\"description\":\"Coordinate 1 as defined by axis 1 of the "
    "specified CRS (e.g., X, Latitude)\"},\"vertical_accuracy\":{\"type\":\"numbe"
    "r\",\"description\":\"Vertical accuracy [m]\",\"exclusiveMinimum\":true,\"mini"
    "mum\":0},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate 3 as"
    " defined by axis 3 of the specified CRS (e.g., Z, "
    "Altitude)\"},\"crs\":{\"description\":\"Global Coordinate Reference System\","
    "\"type\":\"object\",\"properties\":{\"wkt\":{\"type\":\"string\",\"description\":\"\\\""
    "Well-Known Text\\\" string, OGC WKT dialect (see http://www.opengeospati"
    "al.org/standards/wkt-crs)\"},\"epsg\":{\"type\":\"integer\",\"description\":\"EP"
    "SG code\",\"minimum\":0}},\"required\":[\"epsg\"]},\"coordinate_2\":{\"type\":\"nu"
    "mber\",\"description\":\"Coordinate 2 as defined by axis 2 of the "
    "specified CRS (e.g., Y, Longitude)\"},\"horizontal_accuracy\":{\"type\":\"nu"
    "mber\",\"description\":\"Horizontal accuracy [m]\",\"exclusiveMinimum\":true,"
    "\"minimum\":0}},\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\""
    ",\"horizontal_accuracy\",\"vertical_accuracy\",\"crs\"]}},\"title\":\"Pose "
    "Estimation\"}"
    ,
    /* example: */
    "{\"orientation\":{\"pitch_accuracy\":0.009433783936875745,\"yaw_accuracy\":1"
    ".0094337839368757,\"pitch\":1.509153024827064,\"roll_accuracy\":0.00943378"
    "3936875745,\"roll\":3.14743073066123,\"yaw\":101.87293630292045},\"barometr"
    "ic_height_amsl\":386.7457796227932,\"position\":{\"coordinate_1\":48.655799"
    "473,\"vertical_accuracy\":1.3314999341964722,\"coordinate_3\":362.71249389"
    "64844,\"crs\":{\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHE"
    "ROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]]"
    ",AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000"
    ",AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251994329547,"
    "AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitud"
    "e\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\",\"epsg\":4979},\"coordinate_2\":1"
    "5.645033406,\"horizontal_accuracy\":0.810699999332428}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details on position and orientation "
    "sensors\",\"type\":\"object\",\"title\":\"Pose Sensors\",\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"properties\":{\"gyroscope\":{\"description\""
    ":\"Gyroscope "
    "details\",\"type\":\"object\",\"properties\":{\"origin\":{\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in rad/s\",\"type\":\"number\",\"exclusiv"
    "eMinimum\":true,\"minimum\":0},\"relative_nonlinearity\":{\"description\":\"Re"
    "lative nonlinearity, dimensionless\",\"$ref\":\"#/definitions/vector\"},\"x_"
    "axis\":{\"description\":\"Sensitive X axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "}},\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"re"
    "lative_nonlinearity\"]},\"magnetic_field_sensor\":{\"description\":\"Magneti"
    "c Field Sensor details\",\"type\":\"object\",\"properties\":{\"fixed\":{\"descri"
    "ption\":\"Distortion of magnetic field caused by non-rotating scanner pa"
    "rt\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive "
    "Y axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in nT\",\"type\":\"number\",\"exclusiveMi"
    "nimum\":true,\"minimum\":0},\"relative_nonlinearity\":{\"description\":\"Relat"
    "ive nonlinearity, dimensionless\",\"$ref\":\"#/definitions/vector\"},\"x_axi"
    "s\":{\"description\":\"Sensitive X axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "}},\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"rel"
    "ative_nonlinearity\"]},\"accelerometer\":{\"description\":\"Accelerometer "
    "details\",\"type\":\"object\",\"properties\":{\"origin\":{\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"unit\":{\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in 9.81 m/s\\u00b2\",\"type\":\"number\","
    "\"exclusiveMinimum\":true,\"minimum\":0},\"relative_nonlinearity\":{\"descrip"
    "tion\":\"Relative nonlinearity, dimensionless\",\"$ref\":\"#/definitions/vec"
    "tor\"},\"x_axis\":{\"description\":\"Sensitive X axis of sensor at frame "
    "angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "}},\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"re"
    "lative_nonlinearity\"]}},\"definitions\":{\"vector\":{\"minItems\":3,\"type\":\""
    "array\",\"maxItems\":3,\"items\":{\"description\":\"Index 0=X, 1=Y, 2=Z compon"
    "ent\",\"type\":\"number\"}}},\"required\":[\"gyroscope\",\"accelerometer\",\"magne"
    "tic_field_sensor\"]}"
    ,
    /* example: */
    "{\"gyroscope\":{\"origin\":[0.026900000870227814,-0.03999999910593033,-0.0"
    "8950000256299973],\"y_axis\":[-0.440765917301178,-0.7897399663925171,119"
    ".5894775390625],\"z_axis\":[0.555869996547699,119.22135162353516,0.46758"
    "5027217865],\"unit\":0.00014544410805683583,\"relative_nonlinearity\":[2.8"
    "88176311444113e-07,1.06274164579645e-07,-1.7186295080634935e-39],\"x_ax"
    "is\":[-121.195556640625,0.8219714164733887,0.2313031703233719],\"offset\""
    ":[-50.92609786987305,146.15643310546875,62.4327278137207]},\"magnetic_f"
    "ield_sensor\":{\"fixed\":[-1576.010498046875,1596.081787109375,0.0],\"y_ax"
    "is\":[0.00027888521435670555,-0.011427424848079681,-5.204829722060822e-"
    "05],\"z_axis\":[0.00041987866279669106,7.876977906562388e-05,0.011407104"
    "320824146],\"unit\":91.74311828613281,\"relative_nonlinearity\":[0.0,0.0,0"
    ".0],\"x_axis\":[-0.011162743903696537,-2.315962774446234e-05,0.000168188"
    "44596855342],\"offset\":[-23812.052734375,5606.57666015625,2493.28125]},"
    "\"accelerometer\":{\"origin\":[0.026900000870227814,-0.03999999910593033,-"
    "0.08950000256299973],\"y_axis\":[-7.027288913726807,-44.12333679199219,1"
    "4952.3701171875],\"z_axis\":[1.639882206916809,15166.744140625,-116.9974"
    "2889404297],\"unit\":6.666666740784422e-05,\"relative_nonlinearity\":[0.0,"
    "0.0,0.0],\"x_axis\":[-15008.123046875,56.956390380859375,-60.51756668090"
    "82],\"offset\":[-733.3636474609375,58.969032287597656,1060.2550048828125"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Laser pulse position modulation used for MTA resolutio"
    "n\",\"type\":\"object\",\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval"
    "\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\""
    "num_mod_ampl\":{\"maximum\":255,\"description\":\"Number of different "
    "modulation amplitudes (2: binary modulation)\",\"type\":\"integer\",\"minimu"
    "m\":0},\"length\":{\"maximum\":255,\"description\":\"Length of code\",\"type\":\"i"
    "nteger\",\"minimum\":0},\"code_phase_mode\":{\"maximum\":255,\"description\":\"0"
    ": no synchronization, 1: toggle between 2 phases, 2: increment with ph"
    "ase_increment\",\"type\":\"integer\",\"minimum\":0},\"pulse_interval\":{\"descri"
    "ption\":\"Explicit table of the pulse position modulation used for MTA "
    "resolution. Table gives times between successive laser pulses in secon"
    "ds.\",\"type\":\"array\",\"items\":{\"type\":\"number\",\"minimum\":0}},\"phase_step"
    "\":{\"maximum\":255,\"description\":\"Step width in phase of modulation code"
    " from line to line\",\"type\":\"integer\",\"minimum\":0}},\"title\":\"Pulse "
    "Position Modulation\"}"
    ,
    /* example: */
    "{\"num_mod_ampl\":2,\"length\":31,\"code_phase_mode\":2,\"pulse_interval\":[2."
    "759375e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.75937"
    "5e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06"
    ",2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.82"
    "1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e"
    "-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2"
    ".759375e-06,2.821875e-06,2.759375e-06,2.821875e-06],\"phase_step\":5}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Statistics about target distance wrt. SOCS origin\",\"ty"
    "pe\":\"object\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"maximum"
    "\":{\"description\":\"Maximum "
    "value\",\"type\":\"number\"},\"average\":{\"description\":\"Average "
    "value\",\"type\":\"number\"},\"std_dev\":{\"description\":\"Standard "
    "deviation\",\"type\":\"number\"},\"minimum\":{\"description\":\"Minimum "
    "value\",\"type\":\"number\"}},\"title\":\"Range Statistics\"}"
    ,
    /* example: */
    "{\"maximum\":574.35,\"average\":15.49738,\"std_dev\":24.349,\"minimum\":0.919}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Receiver Internals\",\"type\":\"object\",\"title\":\"Receiver "
    "Internals\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"proper"
    "ties\":{\"t\":{\"patternProperties\":{\"^[0-9]+$\":{\"description\":\"one field "
    "per channel, field name is channel index\",\"$ref\":\"#/definitions/fp\"}},"
    "\"type\":\"object\",\"additionalProperties\":false},\"tbl\":{\"minItems\":1,\"des"
    "cription\":\"various internal data\",\"type\":\"array\",\"items\":{\"$ref\":\"#/de"
    "finitions/fp_table\"}},\"nt\":{\"maximum\":255,\"description\":\"Number of tra"
    "ces\",\"type\":\"integer\",\"minimum\":0},\"mw\":{\"maximum\":4095,\"description\":"
    "\"Maximum weight\",\"type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0},"
    "\"ns\":{\"maximum\":4095,\"description\":\"Number of samples\",\"type\":\"integer"
    "\",\"minimum\":0},\"ex\":{\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' "
    "instead\",\"type\":\"object\"},\"sr\":{\"description\":\"Sample rate [Hz]\",\"type"
    "\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0},\"si\":{\"maximum\":255,\"d"
    "escription\":\"Start index (hw_start)\",\"type\":\"number\",\"minimum\":0},\"a\":"
    "{\"minItems\":1,\"description\":\"Amplitude [dB]\",\"type\":\"array\",\"maxItems\""
    ":256,\"items\":{\"type\":\"number\"}}},\"definitions\":{\"fp_table\":{\"desriptio"
    "n\":\"scanner internal "
    "data\",\"type\":\"object\",\"properties\":{\"tc\":{\"description\":\"table data "
    "type code\",\"type\":\"integer\",\"max\":255,\"min\":0},\"tv\":{\"type\":\"array\",\"m"
    "axItems\":2048,\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},"
    "{\"type\":\"number\"}]},\"minItems\":1},\"ch\":{\"description\":\"channel number\""
    ",\"type\":\"integer\",\"max\":255,\"min\":0},\"ny\":{\"description\":\"number of y "
    "entries\",\"type\":\"integer\",\"max\":2048,\"min\":1},\"nx\":{\"description\":\"num"
    "ber of x entries\",\"type\":\"integer\",\"max\":2048,\"min\":1}},\"required\":[\"c"
    "h\",\"tc\",\"nx\",\"ny\",\"tv\"]},\"fp\":{\"description\":\"Fingerprint values\",\"typ"
    "e\":\"object\",\"properties\":{\"s\":{\"minItems\":1,\"type\":\"array\",\"maxItems\":"
    "256,\"items\":{\"minItems\":1,\"type\":\"array\",\"maxItems\":4096,\"items\":{\"typ"
    "e\":\"number\"}}},\"w\":{\"minItems\":1,\"type\":\"array\",\"maxItems\":256,\"items\""
    ":{\"minItems\":5,\"type\":\"array\",\"maxItems\":5,\"items\":{\"type\":\"number\"}}}"
    "},\"required\":[\"s\",\"w\"]},\"fp_table_row\":{\"type\":\"array\",\"maxItems\":2048"
    ",\"items\":{\"type\":\"number\"},\"minItems\":1}}}"
    ,
    /* example: */
    "{\"t\":{\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[78,8"
    "6,126,134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134"
    ",31],[78,86,126,134,31]]}},\"tbl\":[{\"tc\":1,\"tv\":[[1,2,3,4,5],[1.1,2.2,3"
    ".3,4.4,5.5]],\"ch\":0,\"ny\":2,\"nx\":5}],\"nt\":128,\"mw\":31,\"ns\":400,\"sr\":795"
    "9997000.0,\"si\":48,\"a\":[-1.55]}"
};

// List of names of the records
const MetaDataItemInfo RDB_RIEGL_RECORD_NAMES = {
    /* name        */ "riegl.record_names",
    /* title       */ "Record Names",
    /* description */ "List of names of the records",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"List of names of the records\",\"$schema"
    "\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"names\":{\"de"
    "scription\":\"List of record names. The name of a record is the "
    "{riegl.id}th element of this list. The number of elements must "
    "correspond to the maximum riegl.id occurring in this "
    "file.\",\"type\":\"array\",\"items\":{\"type\":\"string\",\"description\":\"Record "
    "name\"}}},\"title\":\"Record Names\"}"
    ,
    /* example: */
    "{\"names\":[\"Name of first record\",\"Name of second record\",\"Name of "
    "third record\",\"Name of fourth record\"]}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Lookup table for reflectance calculation based on "
    "amplitude and range\",\"type\":\"object\",\"required\":[\"delta\",\"content\"],\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"delta"
    "\":{\"type\":\"number\",\"description\":\"Delta between table entries [m], "
    "first entry is at range = 0 "
    "m\"},\"content\":{\"type\":\"array\",\"minItems\":1,\"description\":\"Correction "
    "value [dB] to be added to the amplitude\",\"maxItems\":2000,\"items\":{\"typ"
    "e\":\"number\"}}},\"title\":\"Reflectance Calculation Table\"}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-range reflectance correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Range-dependent and scan-angle-dependent correction of"
    " reflectance reading\",\"type\":\"object\",\"required\":[\"ranges_m\",\"line_ang"
    "les_deg\",\"reflectance_correction_db\"],\"$schema\":\"http://json-schema.or"
    "g/draft-04/schema#\",\"properties\":{\"reflectance_correction_db\":{\"descri"
    "ption\":\"Near range reflectance correction in dB as a function of range"
    " over "
    "angle\",\"type\":\"array\",\"items\":{\"type\":\"array\",\"description\":\"rows "
    "(each array corresponds to a "
    "range)\",\"items\":{\"type\":\"number\",\"description\":\"columns (each value "
    "corresponds to an angle)\"}}},\"ranges_m\":{\"description\":\"Range [m]\",\"ty"
    "pe\":\"array\",\"items\":{\"type\":\"number\"}},\"line_angles_deg\":{\"description"
    "\":\"Angle "
    "[deg]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}}},\"title\":\"Near-range "
    "reflectance correction\"}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"ra"
    "nges_m\":[0.0,1.0,2.0,3.0],\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2"
    ".5,3.0,3.5,4.0]}"
};

// Scan Pattern Description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan Pattern Description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scan Pattern Description\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"properties\":{\"segments\":{\"type\":\"object\",\"des"
    "cription\":\"Segmented Line Scan Pattern\",\"properties\":{\"list\":{\"type\":\""
    "array\",\"items\":{\"type\":\"object\",\"description\":\"Line Scan Segment\",\"pro"
    "perties\":{\"increment\":{\"type\":\"number\",\"maximum\":90.0,\"description\":\"I"
    "ncrement of angle in SOCS [deg]\",\"minimum\":0.0},\"start\":{\"type\":\"numbe"
    "r\",\"maximum\":360.0,\"description\":\"Start angle in SOCS [deg]\",\"minimum\""
    ":0.0},\"stop\":{\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop "
    "angle in SOCS [deg]\",\"minimum\":0.0}},\"required\":[\"start\",\"stop\",\"incre"
    "ment\"]}},\"program\":{\"$ref\":\"#/definitions/program\"}},\"required\":[\"list"
    "\"]},\"line\":{\"type\":\"object\",\"description\":\"Line Scan Pattern\",\"propert"
    "ies\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"increment\":{\"type\":\""
    "number\",\"maximum\":90.0,\"description\":\"Increment of angle in SOCS [deg]"
    "\",\"minimum\":0.0},\"start\":{\"type\":\"number\",\"maximum\":360.0,\"description"
    "\":\"Start angle in SOCS [deg]\",\"minimum\":0.0},\"stop\":{\"type\":\"number\",\""
    "maximum\":720.0,\"description\":\"Stop angle in SOCS [deg]\",\"minimum\":0.0}"
    "},\"required\":[\"start\",\"stop\",\"increment\"]},\"rectangular\":{\"type\":\"obje"
    "ct\",\"description\":\"Rectangular Field Of View Scan Pattern\",\"properties"
    "\":{\"phi_stop\":{\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop phi"
    " angle in SOCS [deg]\",\"minimum\":0.0},\"theta_stop\":{\"type\":\"number\",\"ma"
    "ximum\":180.0,\"description\":\"Stop theta angle in SOCS [deg]\",\"minimum\":"
    "0.0},\"program\":{\"$ref\":\"#/definitions/program\"},\"phi_start\":{\"type\":\"n"
    "umber\",\"maximum\":360.0,\"description\":\"Start phi angle in SOCS [deg]\",\""
    "minimum\":0.0},\"theta_start\":{\"type\":\"number\",\"maximum\":180.0,\"descript"
    "ion\":\"Start theta angle in SOCS [deg]\",\"minimum\":0.0},\"phi_increment\":"
    "{\"type\":\"number\",\"maximum\":90.0,\"description\":\"Increment of phi angle "
    "in SOCS [deg]\",\"minimum\":0.0},\"theta_increment\":{\"type\":\"number\",\"maxi"
    "mum\":90.0,\"description\":\"Increment of theta angle in SOCS [deg]\",\"mini"
    "mum\":0.0}},\"required\":[\"phi_start\",\"phi_stop\",\"phi_increment\",\"theta_s"
    "tart\",\"theta_stop\",\"theta_increment\"]}},\"definitions\":{\"program\":{\"typ"
    "e\":\"object\",\"description\":\"Measurement "
    "program\",\"properties\":{\"name\":{\"type\":\"string\",\"description\":\"Name of "
    "measurement "
    "program\"},\"laser_prr\":{\"type\":\"number\",\"description\":\"Laser Pulse "
    "Repetition Rate [Hz]\",\"exclusiveMinimum\":false,\"minimum\":0}},\"required"
    "\":[\"name\"]}},\"title\":\"Scan Pattern\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_stop\":270.0,\"theta_stop\":130.0,\"program\":{\"name\":"
    "\"High Speed\",\"laser_prr\":100000.0},\"phi_start\":45.0,\"theta_start\":30.0"
    ",\"phi_increment\":0.04,\"theta_increment\":0.04}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about laser shot files\",\"$sche"
    "ma\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"shot_file"
    "\":{\"type\":\"object\",\"properties\":{\"file_extension\":{\"type\":\"string\",\"de"
    "scription\":\"Shot file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"}},\"required\":[\"file_extension\"]}},\"title\":\"Shot Information\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_extension\":\"sodx\",\"file_uuid\":\"26a00815-67c0-4bff-"
    "8fe8-c577378fe663\"}}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Conversion of background radiation raw values to "
    "temperatures in \\u00b0C\",\"type\":\"object\",\"title\":\"Temperature "
    "Calculation Table\",\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"properties\":{\"InGaAs_Si_Difference\":{\"description\":\"Conversion table"
    " for InGaAs - Si difference\",\"$ref\":\"#/definitions/conversion_table\"},"
    "\"InGaAs\":{\"description\":\"Conversion table for InGaAs channel\",\"$ref\":\""
    "#/definitions/conversion_table\"},\"Si\":{\"description\":\"Conversion table"
    " for Si channel\",\"$ref\":\"#/definitions/conversion_table\"}},\"definition"
    "s\":{\"conversion_table\":{\"type\":\"object\",\"properties\":{\"value\":{\"descri"
    "ption\":\"LSB [1]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"temperatur"
    "e\":{\"description\":\"Temperature [\\u00b0C]\",\"type\":\"array\",\"items\":{\"typ"
    "e\":\"number\"}}},\"required\":[\"value\",\"temperature\"]}}}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"value\":[1000.0,1100.090029602954,1200.044251"
    "83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13"
    "27555162209,1700.0869777520065,1800.0411999877924],\"temperature\":[1749"
    ".977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109"
    "2,1622.3944822534868]},\"InGaAs\":{\"value\":[0.0,64.00097659230323,128.00"
    "19531846065,192.0029297769097,256.0039063692129,320.00488296151616,384"
    ".0058595538194,448.0068361461226,512.0078127384259],\"temperature\":[307"
    ".22196722535614,309.1153478247277,311.1188086915047,313.10025350480055"
    ",315.2137946389828,317.2172555057597,319.2207163725366,321.20216118583"
    "25,323.3157023200148]},\"Si\":{\"value\":[0.0,64.00097659230323,128.001953"
    "1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005"
    "8595538194,448.0068361461226,512.0078127384259],\"temperature\":[546.300"
    "048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60"
    "4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0"
    "002936624203]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Base of timestamps (epoch)\",\"type\":\"object\",\"required\""
    ":[\"epoch\",\"source\"],\"$schema\":\"http://json-schema.org/draft-04/schema#"
    "\",\"properties\":{\"epoch\":{\"type\":\"string\",\"description\":\"Date and time "
    "of timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:"
    "00).\"},\"source\":{\"type\":\"string\",\"description\":\"Timestamp source\",\"enu"
    "m\":[\"unknown\",\"RTC\",\"GNSS\"]},\"system\":{\"type\":\"string\",\"description\":\""
    "Time system (time "
    "standard)\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"]}},\"title\":\"Time Base\"}"
    ,
    /* example: */
    "{\"epoch\":\"2015-10-27T00:00:00+00:00\",\"source\":\"GNSS\",\"system\":\"UTC\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about position+orientation files\",\"type\":\"obje"
    "ct\",\"required\":[\"time_interval\",\"navigation_frame\"],\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"properties\":{\"company\":{\"type\":\"str"
    "ing\",\"description\":\"Company "
    "name\"},\"field_of_application\":{\"type\":\"string\",\"description\":\"Field of"
    " application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"B"
    "LS\",\"ILS\"]},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the "
    "file)\"},\"time_interval\":{\"type\":\"object\",\"description\":\"Time interval "
    "statistics\",\"properties\":{\"maximum\":{\"type\":\"number\",\"description\":\"Ma"
    "ximum time interval "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard deviation of "
    "intervals [s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time"
    " interval [s]\"}},\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"]}"
    ",\"settings\":{\"type\":\"string\",\"description\":\"Settings used to calculate"
    " the trajectory (descriptive "
    "text)\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation device, "
    "e.g. name/type/serial\"},\"navigation_frame\":{\"type\":\"string\",\"descripti"
    "on\":\"Navigation frame (NED: North-East-Down, ENU: East-North-Up)\",\"enu"
    "m\":[\"unknown\",\"NED\",\"ENU\"]},\"project\":{\"type\":\"string\",\"description\":\""
    "Project name\"},\"location\":{\"type\":\"string\",\"description\":\"Project "
    "location, e.g. city/state/country\"}},\"title\":\"Trajectory Information\"}"
    ,
    /* example: */
    "{\"company\":\"RIEGL "
    "LMS\",\"field_of_application\":\"MLS\",\"software\":\"Navigation Software XYZ\""
    ",\"time_interval\":{\"maximum\":0.005004883,\"average\":0.00500053,\"std_dev\""
    ":5.51e-07,\"minimum\":0.00500032},\"settings\":\"default\",\"device\":\"IMU "
    "Model 12/1, Serial# "
    "12345\",\"navigation_frame\":\"NED\",\"project\":\"Campaign "
    "3\",\"location\":\"Horn\"}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about vertex file\",\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"properties\":{\"vertex_file\":{"
    "\"type\":\"object\",\"properties\":{\"file_extension\":{\"type\":\"string\",\"descr"
    "iption\":\"Vertex file extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"}},\"required\":[\"file_extension\"]}},\"title\":\"Vertex Information\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_extension\":\"vtx\",\"file_uuid\":\"51534d95-d71f-4f36"
    "-ae1a-3e63a21fd1c7\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the voxels contained in the file\",\"type\""
    ":\"object\",\"definitions\":{\"voxel_type\":{\"default\":\"centroid\",\"descripti"
    "on\":\"Whether a point in a voxel represents its center or its centroid."
    " If type is <tt>index</tt> there is no point but only an integer voxel"
    " index.\",\"enum\":[\"center\",\"centroid\",\"index\"]},\"voxel_origin_enum\":{\"d"
    "efault\":\"corner\",\"description\":\"Defines whether the voxel's center or "
    "a corner is placed on CRS origin <tt>(0/0/0)</tt>.\",\"enum\":[\"center\",\""
    "corner\"]},\"shape_thresholds\":{\"type\":\"object\",\"description\":\"Threshold"
    "s used to compute the voxel's shape_id "
    "value.\",\"properties\":{\"line\":{\"type\":\"number\",\"description\":\"If the "
    "biggest eigenvalue is bigger than the median eigenvalue * "
    "line_threshold, the voxel is considered a line.\",\"exclusiveMinimum\":tr"
    "ue,\"minimum\":1},\"plane\":{\"exclusiveMaximum\":true,\"description\":\"If the"
    " smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\",\"type\":\"number\",\"ma"
    "ximum\":1,\"exclusiveMinimum\":true,\"minimum\":0}},\"required\":[\"plane\",\"li"
    "ne\"]},\"voxel_size_cubic\":{\"type\":\"number\",\"$ref\":\"#/definitions/edge_l"
    "ength\"},\"voxel_origin_point\":{\"type\":\"array\",\"minItems\":3,\"description"
    "\":\"Origin point for all voxel indices in voxel CRS.\",\"maxItems\":3,\"ite"
    "ms\":{\"type\":\"number\"}},\"voxel_size\":{\"type\":\"array\",\"minItems\":3,\"desc"
    "ription\":\"Size of voxels.\",\"maxItems\":3,\"items\":{\"$ref\":\"#/definitions"
    "/edge_length\"}},\"edge_length\":{\"type\":\"number\",\"description\":\"Length "
    "of voxel edge [m].\",\"exclusiveMinimum\":true,\"minimum\":0}},\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"oneOf\":[{\"properties\":{\"voxel"
    "_origin\":{\"$ref\":\"#/definitions/voxel_origin_enum\"},\"size\":{\"oneOf\":[{"
    "\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions/voxel_size_c"
    "ubic\"}],\"description\":\"Size of voxels in file coordinate system.\"},\"sh"
    "ape_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_type\""
    ":{\"$ref\":\"#/definitions/voxel_type\"}},\"required\":[\"size\",\"voxel_origin"
    "\",\"voxel_type\"],\"additionalProperties\":false},{\"properties\":{\"voxel_or"
    "igin\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_origin_enum\"},{\"descripti"
    "on\":\"The base point of the voxel grid. Used together with "
    "<tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual point c"
    "oordinates.\",\"$ref\":\"#/definitions/voxel_origin_point\"}]},\"shape_thres"
    "holds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_type\":{\"$ref\":"
    "\"#/definitions/voxel_type\"},\"reference_point\":{\"type\":\"array\",\"minItem"
    "s\":2,\"description\":\"Point in WGS84 geodetic decimal degree (EPSG:4326)"
    " that was used to compute the projection distortion parameters. The "
    "coefficient order is latitude, longitude. Only voxels with "
    "corresponding geo_tag, voxel_size and reference_point can be reliably "
    "processed together. This entry is available for voxel files in "
    "projected CRS only.\",\"maxItems\":2,\"items\":{\"maximum\":180,\"type\":\"numbe"
    "r\",\"minimum\":-180}},\"size\":{\"description\":\"Size of voxels in file "
    "coordinate system.\",\"$ref\":\"#/definitions/voxel_size\"},\"size_llcs\":{\"d"
    "escription\":\"Size of voxels in a locally levelled cartesian coordinate"
    " system (xyz). This is only used for voxels based on a map projection."
    "\",\"$ref\":\"#/definitions/voxel_size\"}},\"required\":[\"reference_point\",\"s"
    "ize_llcs\",\"size\",\"voxel_origin\",\"voxel_type\"],\"additionalProperties\":f"
    "alse}],\"title\":\"Voxel Information\"}"
    ,
    /* example: */
    "{\"voxel_origin\":\"corner\",\"shape_thresholds\":{\"plane\":0.16,\"line\":6},\"v"
    "oxel_type\":\"centroid\",\"reference_point\":[48,16],\"size\":[0.597164283477"
    "9395,0.5971642834779395,0.5143705304787237],\"size_llcs\":[0.51565752528"
    "91171,0.5130835356683303,0.5143705304787237]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Settings for waveform averaging\",\"type\":\"object\",\"requ"
    "ired\":[\"num_shots\",\"mta_zone\"],\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"properties\":{\"mta_zone\":{\"description\":\"Fixed MTA zone "
    "for averaging.\",\"type\":\"integer\",\"minimum\":1},\"num_shots\":{\"descriptio"
    "n\":\"Number of consecutive shots to be used for averaging.\",\"type\":\"int"
    "eger\",\"minimum\":1},\"trim\":{\"maximum\":0.5,\"description\":\"Percentage for"
    " robust averaging.\",\"type\":\"number\",\"minimum\":0,\"default\":0}},\"title\":"
    "\"Waveform Averaging Settings\"}"
    ,
    /* example: */
    "{\"mta_zone\":1,\"num_shots\":7,\"trim\":0.05}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about waveform files\",\"type\":\"object\",\"require"
    "d\":[\"sample_block_file\",\"sample_data_files\"],\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"properties\":{\"range_offset_m\":{\"type\":\"num"
    "ber\",\"description\":\"Calibrated device specific waveform data range "
    "offset in meters.\"},\"sample_block_file\":{\"type\":\"object\",\"properties\":"
    "{\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block file "
    "extension, without the leading "
    "dot\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC 4122)\"}},\"required\":[\"file_extension\"]},\"sample"
    "_data_files\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\"f"
    "ile_extension\":{\"type\":\"string\",\"description\":\"Sample data file "
    "extension, without the leading "
    "dot\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel "
    "name\"},\"channel\":{\"exclusiveMaximum\":false,\"description\":\"Sample block"
    " channel number (255 = invalid)\",\"type\":\"integer\",\"maximum\":255,\"exclu"
    "siveMinimum\":false,\"minimum\":0},\"sample_bits\":{\"exclusiveMaximum\":fals"
    "e,\"description\":\"Bitwidth of samples (e.g. 10 bit, 12 bit)\",\"type\":\"in"
    "teger\",\"maximum\":32,\"exclusiveMinimum\":false,\"minimum\":0},\"file_uuid\":"
    "{\"type\":\"string\",\"description\":\"File's Universally Unique Identifier "
    "(RFC "
    "4122)\"},\"sample_interval\":{\"type\":\"number\",\"description\":\"Sampling "
    "interval in seconds\",\"exclusiveMinimum\":false,\"minimum\":0},\"delta_st\":"
    "{\"type\":\"number\",\"description\":\"reserved\"},\"laser_wavelength\":{\"type\":"
    "\"number\",\"description\":\"Laser wavelength in meters (0 = unknown)\",\"exc"
    "lusiveMinimum\":false,\"minimum\":0}},\"required\":[\"channel\",\"channel_name"
    "\",\"sample_interval\",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_"
    "extension\"]}}},\"title\":\"Waveform Information\"}"
    ,
    /* example: */
    "{\"range_offset_m\":3.1415,\"sample_block_file\":{\"file_extension\":\"sbx\",\""
    "file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\"},\"sample_data_files\""
    ":[{\"laser_wavelength\":0,\"channel_name\":\"high_power\",\"file_extension\":\""
    "sp0\",\"channel\":0,\"sample_interval\":1.00503e-09,\"file_uuid\":\"da084413-e"
    "3e8-4655-a122-071de8490d8e\",\"sample_bits\":12,\"delta_st\":0},{\"laser_wav"
    "elength\":0,\"channel_name\":\"low_power\",\"file_extension\":\"sp1\",\"channel\""
    ":1,\"sample_interval\":1.00503e-09,\"file_uuid\":\"93585b5e-5ea9-43a1-947b-"
    "e7ba3be642d2\",\"sample_bits\":12,\"delta_st\":0},{\"laser_wavelength\":0,\"ch"
    "annel_name\":\"wwf\",\"file_extension\":\"sp5\",\"channel\":5,\"sample_interval\""
    ":1.00503e-09,\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"sampl"
    "e_bits\":12,\"delta_st\":0}]}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"description\":\"Scanner settings for waveform output\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Waveform S"
    "ettings\",\"items\":{\"type\":\"object\",\"properties\":{\"sbl_name\":{\"type\":\"st"
    "ring\",\"description\":\"Name of sample block, e.g.: wfm, "
    "wwf\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "range less than "
    "[m]\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold"
    " for deviation less than "
    "[1]\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart "
    "waveform output "
    "enabled\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold"
    " for range greater than "
    "[m]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold"
    " for amplitude greater than "
    "[dB]\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold "
    "for deviation greater than "
    "[1]\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\"}},\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_mask\"]}}"
    ,
    /* example: */
    "[{\"sbl_name\":\"wfm\",\"pass_rng_less\":13.11,\"channel_idx_mask\":11,\"enable"
    "d\":true,\"smart_enabled\":true,\"pass_rng_greater\":9.27,\"pass_ampl_greate"
    "r\":1.0,\"pass_ampl_less\":5.0},{\"sbl_name\":\"wwf\",\"channel_idx_mask\":32,\""
    "enabled\":false}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Window analysis data estimated from scandata and "
    "resulting filter parameters\",\"type\":\"object\",\"required\":[\"result\",\"fil"
    "ter\",\"settings\"],\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "properties\":{\"result\":{\"type\":\"object\",\"properties\":{\"range_sigma\":{\"d"
    "escription\":\"[m]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"angle\":{\""
    "description\":\"[deg]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"range_"
    "mean\":{\"description\":\"[m]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}},\""
    "timestamp\":{\"description\":\"[s]\",\"type\":\"array\",\"items\":{\"type\":\"number"
    "\"}},\"amplitude_sigma\":{\"description\":\"[dB]\",\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\"}},\"amplitude_mean\":{\"description\":\"[dB]\",\"type\":\"array\","
    "\"items\":{\"type\":\"number\"}},\"amplitude_offset\":{\"description\":\"[dB]\",\"t"
    "ype\":\"array\",\"items\":{\"type\":\"number\"}}},\"required\":[\"angle\",\"range_me"
    "an\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"amplitude_offset"
    "\"]},\"filter\":{\"type\":\"object\",\"properties\":{\"range_min\":{\"description\""
    ":\"[m]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"angle\":{\"description"
    "\":\"[deg]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"range_max\":{\"desc"
    "ription\":\"[m]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_ma"
    "x\":{\"description\":\"[dB]\",\"type\":\"array\",\"items\":{\"type\":\"number\"}}},\"r"
    "equired\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\"]},\"settings\""
    ":{\"type\":\"object\",\"properties\":{\"range\":{\"type\":\"object\",\"properties\":"
    "{\"sigma_factor\":{\"type\":\"number\"},\"additive_value\":{\"type\":\"number\"}},"
    "\"required\":[\"sigma_factor\",\"additive_value\"]},\"amplitude\":{\"type\":\"obj"
    "ect\",\"properties\":{\"sigma_factor\":{\"type\":\"number\"},\"additive_value\":{"
    "\"type\":\"number\"}},\"required\":[\"sigma_factor\",\"additive_value\"]}},\"requ"
    "ired\":[\"range\",\"amplitude\"]}},\"title\":\"Window Analysis\"}"
    ,
    /* example: */
    "{\"result\":{\"range_sigma\":[0.01869652,0.02151435,0.01747969,0.01918765,"
    "0.01945776,0.01934862,0.01955329,0.02225589,0.02229977,0.01899122,0.02"
    "009433],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15."
    "9],\"range_mean\":[0.1105621,0.1079564,0.1087088,0.1067261,0.1054582,0.1"
    "090412,0.102871,0.1019044,0.1051523,0.1058445,0.1031261],\"timestamp\":["
    "408.4441,411.4443],\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0."
    "4283583,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0."
    "4540681],\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.09778"
    "2,5.116479,5.051756,4.983473,5.007885,5.002441,4.982],\"amplitude_offse"
    "t\":[1.9,1.9]},\"filter\":{\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216"
    ",-0.218,-0.219,-0.221,-0.223,-0.225,-0.227],\"angle\":[14.9,15.0,15.1,15"
    ".2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"range_max\":[0.424,0.425,0.426,"
    "0.427,0.428,0.428,0.429,0.43,0.431,0.431,0.432],\"amplitude_max\":[8.04,"
    "8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78]},\"settings\":{\"range\":"
    "{\"sigma_factor\":8,\"additive_value\":0.1},\"amplitude\":{\"sigma_factor\":4,"
    "\"additive_value\":1.0}}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Correction parameters for window glass echoes\",\"type\":"
    "\"object\",\"required\":[\"amplitude\",\"range\",\"slices\"],\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"properties\":{\"slices\":{\"type\":\"array"
    "\",\"items\":{\"description\":\"Window echo correction parameter slice\",\"typ"
    "e\":\"object\",\"properties\":{\"table\":{\"minItems\":1,\"description\":\"Correct"
    "ion table (dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"type\":\"array\",\"items\":{\"minItems\":1,\"description\":\"Table "
    "row (= amplitude "
    "axis)\",\"type\":\"array\",\"items\":{\"minItems\":3,\"description\":\"Table "
    "column (= range axis)\",\"type\":\"array\",\"maxItems\":3,\"items\":{\"type\":\"nu"
    "mber\",\"description\":\"Table cell (item 0: amplitude in dB, 1: range in "
    "m, 2: flags)\"}}}},\"amplitude\":{\"description\":\"Window echo amplitude of"
    " slice in dB\",\"type\":\"number\"}},\"required\":[\"amplitude\",\"table\"]}},\"ra"
    "nge\":{\"description\":\"Range axis of correction table\",\"type\":\"object\",\""
    "properties\":{\"maximum\":{\"maximum\":2.0,\"description\":\"Maximum range in "
    "m\",\"type\":\"number\",\"minimum\":-2.0},\"entries\":{\"description\":\"Number of"
    " range entries\",\"type\":\"integer\",\"minimum\":1},\"minimum\":{\"maximum\":2.0"
    ",\"description\":\"Minimum range in m\",\"type\":\"number\",\"minimum\":-2.0}},\""
    "required\":[\"minimum\",\"maximum\",\"entries\"]},\"amplitude\":{\"description\":"
    "\"Amplitude axis of correction "
    "table\",\"type\":\"object\",\"properties\":{\"maximum\":{\"description\":\"Maximum"
    " amplitude in "
    "dB\",\"type\":\"number\",\"minimum\":0.0},\"entries\":{\"description\":\"Number of"
    " amplitude entries\",\"type\":\"integer\",\"minimum\":1},\"minimum\":{\"descript"
    "ion\":\"Minimum amplitude in dB\",\"type\":\"number\",\"minimum\":0.0}},\"requir"
    "ed\":[\"minimum\",\"maximum\",\"entries\"]}},\"title\":\"Window Echo "
    "Correction\"}"
    ,
    /* example: */
    "{\"slices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\""
    ":1.5},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}"
    "],\"range\":{\"maximum\":1.5060822940732335,\"entries\":128,\"minimum\":-1.506"
    "0822940732335},\"amplitude\":{\"maximum\":20,\"entries\":128,\"minimum\":2}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_RECORD_NAMES,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
